WebSocket class

Implemented types

Constructors

WebSocket()

Properties

closeCode → int?
no setter
closeReason → String?
no setter
done → Future
no setter
extensions → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
protocol → String?
no setter
readyState → int?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → Stream
no setter

Methods

add(dynamic data) → void
addStream(Stream stream) → Future
Consumes the elements of stream.
override
addUtf8Text(List<int> bytes) → void
close([int? code, String? reason]) → Future
Tells the consumer that no further streams will be added.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

connect(String url, {Iterable<String>? protocols}) → Future<WebSocket>